@@ -165,8 +165,11 @@ class axidma:
         return self.phy_buf.write(raw_bytes,offset)
     def buf_read(self,size,offset=0):
         return self.phy_buf.read(size,offset)
-    def is_idle(self):
-        isIdle = getbit(self.axil.read32(SR_ADDR),0) or getbit(self.axil.read32(SR_ADDR),1) #halt or idle
+    def mm2s_is_idle(self):
+        isIdle = getbit(self.axil.read32(0x4),0) or getbit(self.axil.read32(0x4),1) #halt or idle
+        return isIdle
+    def s2mm_is_idle(self):
+        isIdle = getbit(self.axil.read32(0x34),0) or getbit(self.axil.read32(0x34),1) #halt or idle
         return isIdle
     def __mm2s(self,addr,size,timeout,sync):
         CR_ADDR = 0x0
@@ -174,7 +177,7 @@ class axidma:
         SA_ADDR = 0x18
         LEN_ADDR = 0x28
         for i in range(timeout):
-            if self.is_idle() == 1:
+            if self.mm2s_is_idle() == 1:
                 break
             else:
                 time.sleep(0.001)
@@ -190,7 +193,7 @@ class axidma:
         self.axil.write32(newCtrlVal,CR_ADDR) #set start to 0
         if sync:
             for i in range(timeout):
-                if self.is_idle() == 1:
+                if self.mm2s_is_idle() == 1:
                     break
                 else:
                     time.sleep(0.001)
@@ -204,7 +207,7 @@ class axidma:
         DA_ADDR = 0x48
         LEN_ADDR = 0x58
         for i in range(timeout):
-            if self.is_idle() == 1:
+            if self.s2mm_is_idle() == 1:
                 break
             else:
                 time.sleep(0.001)
@@ -220,7 +223,7 @@ class axidma:
         self.axil.write32(newCtrlVal,CR_ADDR) #set start to 0
         if sync:
             for i in range(timeout):
-                if self.is_idle() == 1:
+                if self.s2mm_is_idle() == 1:
                     break
                 else:
                     time.sleep(0.001)
@@ -268,7 +271,7 @@ class axicdma:
         self.axil = axilite(axil_offset)
         self.dma_bufsize = 2**23
     def is_idle(self):
-        isIdle = getbit(self.axil.read32(SR_ADDR),1) #idle
+        isIdle = getbit(self.axil.read32(0x4),1) #idle
         return isIdle
     def __movedata(self,src_addr,dst_addr,size,timeout,sync):
         CR_ADDR = 0x0
