@@ -32,9 +32,6 @@ def addr_cal(addr,length):
     return [mem_start, mem_span, trans_start]
 
 class axilite:
-    size = -1
-    mem = None
-    fd = -1
     def __init__(self,addr=0,size=0x1000,xdma_channel=0):
         dev_fpath = '/dev/xdma%d_user' % xdma_channel
         if addr%mmap.PAGESIZE != 0:
@@ -97,7 +94,6 @@ class axilite:
             self.fd = -1
 
 class xdma_h2c:
-    fd = None
     def __init__(self,dev_fpath='/dev/xdma0_h2c_0'):
         try:
             self.fd = os.open(dev_fpath,os.O_RDWR)
@@ -115,7 +111,6 @@ class xdma_h2c:
             self.fd = None
 
 class xdma_c2h:
-    fd = None
     def __init__(self,dev_fpath='/dev/xdma0_c2h_0'):
         try:
             self.fd = os.open(dev_fpath,os.O_RDWR)
@@ -133,9 +128,6 @@ class xdma_c2h:
             self.fd = None
 
 class fpgamem:
-    h2c = None
-    c2h = None
-    fpgabase_addr = 0
     def __init__(self,h2c_fpath='/dev/xdma0_h2c_0',c2h_fpath='/dev/xdma0_c2h_0',fpgamem_mapbase=0):
         self.h2c = xdma_h2c(h2c_fpath)
         self.c2h = xdma_c2h(c2h_fpath)
